/
usr
/
include
/
boost
/
compute
/
algorithm
/
/usr/include/boost/compute/algorithm
mkdir
upload
Name
Size
Mode
Actions
detail/
-
0755
rm
accumulate.hpp
6375
0644
edit
dl
rm
adjacent_difference.hpp
4416
0644
edit
dl
rm
adjacent_find.hpp
5313
0644
edit
dl
rm
all_of.hpp
1427
0644
edit
dl
rm
any_of.hpp
1544
0644
edit
dl
rm
binary_search.hpp
1480
0644
edit
dl
rm
copy.hpp
31483
0644
edit
dl
rm
copy_if.hpp
2574
0644
edit
dl
rm
copy_n.hpp
1940
0644
edit
dl
rm
count.hpp
2103
0644
edit
dl
rm
count_if.hpp
2388
0644
edit
dl
rm
equal.hpp
2209
0644
edit
dl
rm
equal_range.hpp
1636
0644
edit
dl
rm
exclusive_scan.hpp
4042
0644
edit
dl
rm
fill.hpp
10030
0644
edit
dl
rm
fill_n.hpp
1367
0644
edit
dl
rm
find.hpp
2004
0644
edit
dl
rm
find_end.hpp
4772
0644
edit
dl
rm
find_if.hpp
1504
0644
edit
dl
rm
find_if_not.hpp
1652
0644
edit
dl
rm
for_each.hpp
2131
0644
edit
dl
rm
for_each_n.hpp
1423
0644
edit
dl
rm
gather.hpp
2796
0644
edit
dl
rm
generate.hpp
1903
0644
edit
dl
rm
generate_n.hpp
1277
0644
edit
dl
rm
includes.hpp
5615
0644
edit
dl
rm
inclusive_scan.hpp
3402
0644
edit
dl
rm
inner_product.hpp
3849
0644
edit
dl
rm
inplace_merge.hpp
2047
0644
edit
dl
rm
iota.hpp
1735
0644
edit
dl
rm
is_partitioned.hpp
1785
0644
edit
dl
rm
is_permutation.hpp
2744
0644
edit
dl
rm
is_sorted.hpp
2436
0644
edit
dl
rm
lexicographical_compare.hpp
4950
0644
edit
dl
rm
lower_bound.hpp
1573
0644
edit
dl
rm
max_element.hpp
2781
0644
edit
dl
rm
merge.hpp
5037
0644
edit
dl
rm
minmax_element.hpp
2668
0644
edit
dl
rm
min_element.hpp
2780
0644
edit
dl
rm
mismatch.hpp
3409
0644
edit
dl
rm
next_permutation.hpp
5703
0644
edit
dl
rm
none_of.hpp
1426
0644
edit
dl
rm
nth_element.hpp
2868
0644
edit
dl
rm
partial_sum.hpp
1676
0644
edit
dl
rm
partition.hpp
1523
0644
edit
dl
rm
partition_copy.hpp
2592
0644
edit
dl
rm
partition_point.hpp
1858
0644
edit
dl
rm
prev_permutation.hpp
5695
0644
edit
dl
rm
random_shuffle.hpp
3010
0644
edit
dl
rm
reduce.hpp
11454
0644
edit
dl
rm
reduce_by_key.hpp
5933
0644
edit
dl
rm
remove.hpp
2002
0644
edit
dl
rm
remove_if.hpp
1850
0644
edit
dl
rm
replace.hpp
2588
0644
edit
dl
rm
replace_copy.hpp
2230
0644
edit
dl
rm
reverse.hpp
2438
0644
edit
dl
rm
reverse_copy.hpp
2678
0644
edit
dl
rm
rotate.hpp
1813
0644
edit
dl
rm
rotate_copy.hpp
1529
0644
edit
dl
rm
scatter.hpp
3435
0644
edit
dl
rm
scatter_if.hpp
4730
0644
edit
dl
rm
search.hpp
2967
0644
edit
dl
rm
search_n.hpp
4428
0644
edit
dl
rm
set_difference.hpp
6941
0644
edit
dl
rm
set_intersection.hpp
6646
0644
edit
dl
rm
set_symmetric_difference.hpp
7533
0644
edit
dl
rm
set_union.hpp
7384
0644
edit
dl
rm
sort.hpp
6569
0644
edit
dl
rm
sort_by_key.hpp
6156
0644
edit
dl
rm
stable_partition.hpp
2737
0644
edit
dl
rm
stable_sort.hpp
3809
0644
edit
dl
rm
stable_sort_by_key.hpp
6071
0644
edit
dl
rm
swap_ranges.hpp
1870
0644
edit
dl
rm
transform.hpp
3252
0644
edit
dl
rm
transform_if.hpp
4737
0644
edit
dl
rm
transform_reduce.hpp
3683
0644
edit
dl
rm
unique.hpp
2565
0644
edit
dl
rm
unique_copy.hpp
6429
0644
edit
dl
rm
upper_bound.hpp
1561
0644
edit
dl
rm
Edit:
/usr/include/boost/compute/algorithm/lexicographical_compare.hpp
(4950B)
//---------------------------------------------------------------------------// // Copyright (c) 2014 Mageswaran.D <mageswaran1989@gmail.com> // // Distributed under the Boost Software License, Version 1.0 // See accompanying file LICENSE_1_0.txt or copy at // http://www.boost.org/LICENSE_1_0.txt // // See http://boostorg.github.com/compute for more information. //---------------------------------------------------------------------------// #include <boost/static_assert.hpp> #include <boost/compute/system.hpp> #include <boost/compute/context.hpp> #include <boost/compute/command_queue.hpp> #include <boost/compute/algorithm/any_of.hpp> #include <boost/compute/container/vector.hpp> #include <boost/compute/utility/program_cache.hpp> #include <boost/compute/type_traits/is_device_iterator.hpp> namespace boost { namespace compute { namespace detail { const char lexicographical_compare_source[] = "__kernel void lexicographical_compare(const uint size1,\n" " const uint size2,\n" " __global const T1 *range1,\n" " __global const T2 *range2,\n" " __global bool *result_buf)\n" "{\n" " const uint i = get_global_id(0);\n" " if((i != size1) && (i != size2)){\n" //Individual elements are compared and results are stored in parallel. //0 is true " if(range1[i] < range2[i])\n" " result_buf[i] = 0;\n" " else\n" " result_buf[i] = 1;\n" " }\n" " else\n" " result_buf[i] = !((i == size1) && (i != size2));\n" "}\n"; template<class InputIterator1, class InputIterator2> inline bool dispatch_lexicographical_compare(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2, command_queue &queue) { const boost::compute::context &context = queue.get_context(); boost::shared_ptr<program_cache> cache = program_cache::get_global_cache(context); size_t iterator_size1 = iterator_range_size(first1, last1); size_t iterator_size2 = iterator_range_size(first2, last2); size_t max_size = (std::max)(iterator_size1, iterator_size2); if(max_size == 0){ return false; } boost::compute::vector<bool> result_vector(max_size, context); typedef typename std::iterator_traits<InputIterator1>::value_type value_type1; typedef typename std::iterator_traits<InputIterator2>::value_type value_type2; // load (or create) lexicographical compare program std::string cache_key = std::string("__boost_lexicographical_compare") + type_name<value_type1>() + type_name<value_type2>(); std::stringstream options; options << " -DT1=" << type_name<value_type1>(); options << " -DT2=" << type_name<value_type2>(); program lexicographical_compare_program = cache->get_or_build( cache_key, options.str(), lexicographical_compare_source, context ); kernel lexicographical_compare_kernel(lexicographical_compare_program, "lexicographical_compare"); lexicographical_compare_kernel.set_arg<uint_>(0, iterator_size1); lexicographical_compare_kernel.set_arg<uint_>(1, iterator_size2); lexicographical_compare_kernel.set_arg(2, first1.get_buffer()); lexicographical_compare_kernel.set_arg(3, first2.get_buffer()); lexicographical_compare_kernel.set_arg(4, result_vector.get_buffer()); queue.enqueue_1d_range_kernel(lexicographical_compare_kernel, 0, max_size, 0); return boost::compute::any_of(result_vector.begin(), result_vector.end(), _1 == 0, queue); } } // end detail namespace /// Checks if the first range [first1, last1) is lexicographically /// less than the second range [first2, last2). /// /// Space complexity: /// \Omega(max(distance(\p first1, \p last1), distance(\p first2, \p last2))) template<class InputIterator1, class InputIterator2> inline bool lexicographical_compare(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2, command_queue &queue = system::default_queue()) { BOOST_STATIC_ASSERT(is_device_iterator<InputIterator1>::value); BOOST_STATIC_ASSERT(is_device_iterator<InputIterator2>::value); return detail::dispatch_lexicographical_compare(first1, last1, first2, last2, queue); } } // end compute namespace } // end boost namespac
Save
cmd:
run